==> v0.7.12.tar.gz: antares/src/renderer/i18n/zh-CN.ts <==
export const zhCN = {
   word: {
      edit: '编辑',
      save: '保存',
      close: '关闭',
      delete: '删除',
      confirm: '确定',
      cancel: '取消',
      send: '发送',
      connectionName: '连接名称',
      client: '数据库类型',
      hostName: '主机名',
      port: '端口',
      user: '用户',
      password: '密码',
      credentials: '凭据',
      connect: '连接',
      connected: '已连接',
      disconnect: '断开连接',
      disconnected: '断开连接',
      refresh: '刷新',
      settings: '设置',
      general: '常规',
      themes: '主题',
      update: '更新',
      about: '关于',
      language: '语言',
      version: '版本',
      donate: '捐赠',
      run: '运行',
      schema: '模式(schema)',
      results: '结果',
      size: '尺寸',
      seconds: '秒',
      type: '类型',
      mimeType: 'MIME类型',
      download: '下载',
      add: '新增',
      data: '数据',
      properties: '属性',
      insert: '插入',
      connecting: '连接中',
      name: '名称',
      collation: '排序规则',
      clear: '清除',
      options: '选项',
      autoRefresh: '自动刷新',
      indexes: '索引',
      foreignKeys: '外键',
      length: '长度',
      unsigned: '无符号',
      default: '默认',
      comment: '注释',
      key: '键位 | 键位',
      order: '排序',
      expression: '表达式',
      autoIncrement: '自动增量',
      engine: '引擎',
      field: '字段 | 字段',
      approximately: '大约',
      total: '总计',
      table: '表',
      discard: '丢弃',
      stay: '等待',
      author: '作者',
      light: '明亮',
      dark: '暗黑',
      autoCompletion: '自动完成',
      application: '应用程序',
      editor: '编辑器',
      view: '视图',
      definer: '定义者',
      algorithm: '算法',
      trigger: '触发器 | 触发器',
      storedRoutine: '存储例程 | 存储例程',
      scheduler: '调度器 | 调度器',
      event: '事件',
      parameters: '参数',
      function: '函数 | 函数',
      deterministic: '确定的',
      context: '上下文',
      export: '导出',
      import: '导入',
      returns: '返回',
      timing: '定时',
      state: '状态',
      execution: '执行',
      starts: '开始',
      ends: '结束',
      ssl: 'SSL',
      privateKey: '私钥',
      certificate: '证书',
      caCertificate: 'CA 证书',
      ciphers: '密码',
      upload: '上传',
      browse: '浏览',
      faker: '伪造者',
      content: '内容',
      cut: '剪切',
      copy: '复制',
      paste: '粘贴',
      tools: '工具',
      variables: '变量',
      processes: '进程',
      database: '数据库',
      scratchpad: '草稿栏',
      array: '数组',
      changelog: '变更日志',
      format: '格式',
      sshTunnel: 'SSH 隧道',
      structure: '结构',
      small: '小',
      medium: '中',
      large: '大',
      row: '行 | 行',
      cell: '单元格 | 单元格',
      triggerFunction: '触发函数 | 触发函数',
      all: '全部',
      duplicate: '重复',
      routine: '例程',
      new: '新',
      history: '历史',
      select: '选择',
      passphrase: '密码短语',
      filter: '过滤器',
      change: '变更',
      views: '视图',
      triggers: '触发器',
      routines: '例程',
      functions: '函数',
      schedulers: '调度器',
      includes: '包含',
      drop: '下降',
      completed: '已完成',
      aborted: '中止',
      disabled: '禁用',
      enable: '启用',
      disable: '禁用',
      commit: '提交',
      rollback: '回滚',
      connectionString: '连接字符串',
      contributors: '贡献者',
      pin: '固定',
      unpin: '取消固定',
      console: '控制台',
      shortcuts: '快捷键',
      folder: '文件夹 | 文件夹',
      appearance: '外观',
      color: '颜色',
      label: '标签',
      icon: '图标',
      resultsTable: '结果表'
   },
   message: {
      appWelcome: '欢迎来到Antares SQL Client!',
      appFirstStep: '你的第一步: 创建一个新的数据库连接.',
      addConnection: '添加连接',
      createConnection: '创建连接',
      createNewConnection: '创建新连接',
      askCredentials: '询问凭据',
      testConnection: '测试连接',
      editConnection: '编辑连接',
      deleteConnection: '删除连接',
      deleteConfirm: '您是否确认取消',
      connectionSuccessfullyMade: '连接成功了!',
      madeWithJS: '使用 💛 和 JavaScript 制作!',
      checkForUpdates: '检查更新',
      noUpdatesAvailable: '无可用更新',
      checkingForUpdate: '正在检查更新',
      checkFailure: '检查失败，请稍后再试',
      updateAvailable: '可用更新',
      downloadingUpdate: '正在下载更新',
      updateDownloaded: '已下载更新',
      restartToInstall: '重启 Antares 以进行安装',
      unableEditFieldWithoutPrimary: '无法编辑结果集中一个没有主键的字段',
      editCell: '编辑单元格',
      deleteRows: '删除行 | 删除 {count} 行',
      confirmToDeleteRows: '您是否确认要删除一行? | 您是否确认要删除 {count} 行?',
      notificationsTimeout: '通知超时',
      uploadFile: '上传文件',
      addNewRow: '添加新行',
      numberOfInserts: '插入的数量',
      openNewTab: '打开一个新标签',
      affectedRows: '受影响的行',
      createNewDatabase: '创建新数据库',
      databaseName: '数据库名称',
      serverDefault: '默认服务器',
      deleteDatabase: '删除数据库',
      editDatabase: '编辑数据库',
      clearChanges: '清除更改',
      addNewField: '添加新字段',
      manageIndexes: '管理索引',
      manageForeignKeys: '管理外键',
      allowNull: '允许 NULL',
      zeroFill: '零填充',
      customValue: '自定义值',
      onUpdate: '在更新',
      deleteField: '删除字段',
      createNewIndex: '创建新索引',
      addToIndex: '添加到索引',
      createNewTable: '创建新表',
      emptyTable: '清空表',
      deleteTable: '删除表',
      emptyConfirm: '您是否确认清空',
      unsavedChanges: '未保存的更改',
      discardUnsavedChanges: '您有一些未保存的更改, 关闭此标签将放弃这些更改.',
      thereAreNoIndexes: '没有索引',
      thereAreNoForeign: '没有外键',
      createNewForeign: '创建新外键',
      referenceTable: '参考表',
      referenceField: '参考字段',
      foreignFields: '外键字段',
      invalidDefault: '无效的默认值',
      onDelete: '在删除',
      applicationTheme: '应用程序主题',
      editorTheme: '编辑器主题',
      wrapLongLines: '将长行换行显示',
      selectStatement: '选择语句',
      triggerStatement: '触发器语句',
      sqlSecurity: 'SQL 安全',
      updateOption: '更新选项',
      deleteView: '删除视图',
      createNewView: '创建新视图',
      deleteTrigger: '删除触发器',
      createNewTrigger: '创建新触发器',
      currentUser: '当前用户',
      routineBody: '例程主体',
      dataAccess: '数据访问',
      thereAreNoParameters: '没有参数',
      createNewParameter: '创建新参数',
      createNewRoutine: '创建新存储例程',
      deleteRoutine: '删除存储例程',
      functionBody: '函数体',
      createNewFunction: '创建新函数',
      deleteFunction: '删除函数',
      schedulerBody: '调度器主体',
      createNewScheduler: '创建新调度器',
      deleteScheduler: '删除调度器',
      preserveOnCompletion: '完成时保存',
      enableSsl: '启用 SSL',
      manualValue: '手动值',
      tableFiller: '表填充器',
      fakeDataLanguage: '伪造的数据语言',
      searchForElements: '搜索元素',
      selectAll: '选择全部',
      queryDuration: '查询时间',
      includeBetaUpdates: '包含测试版的更新',
      setNull: '设置 NULL',
      processesList: '进程列表',
      processInfo: '进程信息',
      manageUsers: '管理用户',
      createNewSchema: '创建新模式(schema)',
      schemaName: '模式名称',
      editSchema: '编辑模式',
      deleteSchema: '删除模式',
      markdownSupported: '支持 Markdown',
      plantATree: '种植一棵树',
      dataTabPageSize: '数据标签的页面大小',
      enableSsh: '启用 SSH',
      pageNumber: '页数',
      duplicateTable: '重复的表',
      noOpenTabs: '没有打开的标签, 请在左侧栏上导航或:',
      noSchema: '没有模式',
      restorePreviousSession: '恢复上一个会话',
      runQuery: '运行查询',
      thereAreNoTableFields: '没有表的字段',
      newTable: '新表',
      newView: '新视图',
      newTrigger: '新触发器',
      newRoutine: '新例程',
      newFunction: '新函数',
      newScheduler: '新调度器',
      newTriggerFunction: '新触发函数',
      thereIsNoQueriesYet: '目前还没有任何查询',
      searchForQueries: '搜索查询',
      killProcess: '终止进程',
      closeTab: '关闭标签',
      exportSchema: '导出模式(schema)',
      importSchema: '导入模式(schema)',
      directoryPath: '目录路径',
      newInsertStmtEvery: '每条新的 INSERT 语句',
      processingTableExport: '处理 {table}',
      fetchingTableExport: '正在获取 {table} 数据',
      writingTableExport: '正在写入 {table} 数据',
      checkAllTables: '勾选所有表',
      uncheckAllTables: '不勾选所有表',
      goToDownloadPage: '转到下载页面',
      readOnlyMode: '只读模式',
      killQuery: '取消查询',
      insertRow: '插入行 | 插入多行',
      commitMode: '提交模式',
      autoCommit: '自动提交',
      manualCommit: '手动提交',
      actionSuccessful: '{action} 成功',
      importQueryErrors: '警告: 发生了 {n} 个错误 | 警告: 发生了 {n} 个错误',
      executedQueries: '{n} 个查询已执行 | {n} 个查询已执行',
      outputFormat: '输出格式',
      singleFile: '单个 {ext} 文件',
      zipCompressedFile: 'ZIP 压缩 {ext} 文件',
      disableBlur: '禁用模糊',
      untrustedConnection: '不受信任的连接',
      missingOrIncompleteTranslation: '有缺失或不完整的翻译?',
      findOutHowToContribute: '了解如何做出贡献',
      disableFKChecks: '禁用外键检查',
      allConnections: '所有连接',
      searchForConnections: '搜索连接',
      disableScratchpad: '禁用草稿栏',
      reportABug: '报告错误',
      nextTab: '下一个标签',
      previousTab: '上一个标签',
      selectTabNumber: '选择标签编号 {param}',
      toggleConsole: '切换控制台',
      addShortcut: '添加快捷键',
      editShortcut: '编辑快捷键',
      deleteShortcut: '删除快捷键',
      restoreDefaults: '恢复默认值',
      restoreDefaultsQuestion: '是否确认恢复默认值?',
      registerAShortcut: '注册快捷键',
      invalidShortcutMessage: '无效组合,请继续输入',
      shortcutAlreadyExists: '快捷键已经存在',
      saveContent: '保存内容',
      openAllConnections: '打开全部连接',
      openSettings: '打开设置',
      openScratchpad: '打开草稿栏',
      runOrReload: '运行或重新加载',
      formatQuery: '格式查询',
      queryHistory: '查询历史',
      clearQuery: '清除查询',
      openFilter: '打开过滤器',
      nextResultsPage: '下一个结果页',
      previousResultsPage: '上一个结果页',
      fillCell: '填充单元格',
      editFolder: '编辑文件夹',
      folderName: '文件夹名称',
      deleteFolder: '删除文件夹',
      editConnectionAppearance: '编辑连接的外观',
      executeSelectedQuery: '执行所选查询',
      defaultCopyType: '默认复制类型',
      showTableSize: '在侧边栏显示表大小',
      showTableSizeDescription: '仅限 MySQL/MariaDB. 启用此选项可能会影响许多表的模式(schema)的性能.'
   },
   faker: {
      address: '地址',
      commerce: '商业',
      company: '公司',
      database: '数据库',
      date: '日期',
      finance: '财务',
      git: 'Git',
      hacker: '黑客',
      internet: '互联网',
      lorem: 'Lorem',
      name: '姓名',
      music: '音乐',
      phone: '电话',
      random: '随机',
      system: '系统',
      time: '时间',
      vehicle: '车辆',
      zipCode: '邮政编码',
      zipCodeByState: '各州的邮政编码',
      city: '城市',
      cityPrefix: '城市前缀',
      citySuffix: '城市后缀',
      streetName: '街道名称',
      streetAddress: '街道地址',
      streetSuffix: '街道后缀',
      streetPrefix: '街道前缀',
      secondaryAddress: '次要地址',
      county: '县',
      country: '国家',
      countryCode: '国家代码',
      state: '州',
      stateAbbr: '州简称',
      latitude: '纬度',
      longitude: '经度',
      direction: '方向',
      cardinalDirection: '方位',
      ordinalDirection: '顺序方向',
      nearbyGPSCoordinate: '附近的 GPS 坐标',
      timeZone: '时区',
      color: '颜色',
      department: '部门',
      productName: '产品名称',
      price: '价格',
      productAdjective: '产品形容词',
      productMaterial: '产品材料',
      product: '产品',
      productDescription: '产品说明',
      suffixes: '后缀',
      companyName: '公司名称',
      companySuffix: '公司后缀',
      catchPhrase: '流行语',
      bs: 'BS',
      catchPhraseAdjective: '流行语形容词',
      catchPhraseDescriptor: '流行语说明',
      catchPhraseNoun: '流行语名词',
      bsAdjective: 'BS 形容词',
      bsBuzz: 'BS 嗡嗡声',
      bsNoun: 'BS 名称',
      column: '列',
      type: '类型',
      collation: '排序规则',
      engine: '引擎',
      past: '过去',
      now: '现在',
      future: '未来',
      between: '之间',
      recent: '最近',
      soon: '很快',
      month: '月',
      weekday: '工作日',
      account: '账户',
      accountName: '账户名称',
      routingNumber: '路由编号',
      mask: '掩码',
      amount: '金额',
      transactionType: '交易类型',
      currencyCode: '货币代码',
      currencyName: '货币名称',
      currencySymbol: '货币符号',
      bitcoinAddress: '比特币地址',
      litecoinAddress: '莱特币地址',
      creditCardNumber: '信用卡号码',
      creditCardCVV: '信用卡CVV',
      ethereumAddress: '以太坊地址',
      iban: 'Iban',
      bic: 'Bic',
      transactionDescription: '交易描述',
      branch: '分支',
      commitEntry: '提交条目',
      commitMessage: '提交信息',
      commitSha: '提交 SHA',
      shortSha: '短的 SHA',
      abbreviation: '缩写',
      adjective: '形容词',
      noun: '名词',
      verb: '动词',
      ingverb: '英式动词',
      phrase: '短语',
      avatar: '头像',
      email: '电子邮箱',
      exampleEmail: '示例电子邮件',
      userName: '用户名',
      protocol: '协议',
      url: '统一资源定位地址',
      domainName: '域名',
      domainSuffix: '域名后缀',
      domainWord: '域词',
      ip: 'Ip',
      ipv6: 'Ipv6',
      userAgent: '用户代理',
      mac: 'Mac',
      password: '密码',
      word: '单词',
      words: '单词',
      sentence: '句子',
      slug: 'Slug',
      sentences: '句子',
      paragraph: '段落',
      paragraphs: '段落',
      text: '文本',
      lines: '行',
      genre: '类型',
      firstName: '名',
      lastName: '姓氏',
      middleName: '中间名',
      findName: '全名',
      jobTitle: '职位名称',
      gender: '性别',
      prefix: '前缀',
      suffix: '后缀',
      title: '头衔',
      jobDescriptor: '工作描述',
      jobArea: '工作领域',
      jobType: '工作类型',
      phoneNumber: '电话号码',
      phoneNumberFormat: '电话号码格式',
      phoneFormats: '电话格式',
      number: '号码',
      float: 'Float',
      arrayElement: '数组元素',
      arrayElements: '数组元素',
      objectElement: '对象元素',
      uuid: 'Uuid',
      boolean: '布尔型',
      image: '镜像',
      locale: '区域',
      alpha: '阿尔法',
      alphaNumeric: 'α 数字',
      hexaDecimal: '十六进制',
      fileName: '文件名',
      commonFileName: '普通文件名',
      mimeType: 'MIME类型',
      commonFileType: '常见文件类型',
      commonFileExt: '常见文件扩展名',
      fileType: '文件类型',
      fileExt: '文件扩展名',
      directoryPath: '目录路径',
      filePath: '文件路径',
      semver: 'Semver',
      manufacturer: '制造商',
      model: '型号',
      fuel: 'Fuel',
      vin: 'Vin'
   }
};

==> v0.7.17.tar.gz: antares/src/renderer/i18n/zh-CN.ts <==
export const zhCN = {
   general: {
      edit: '编辑',
      save: '保存',
      close: '关闭',
      delete: '删除',
      confirm: '确定',
      cancel: '取消',
      send: '发送',
      refresh: '刷新',
      autoRefresh: '自动刷新',
      version: '版本',
      donate: '捐赠',
      run: '运行',
      results: '结果',
      size: '尺寸',
      mimeType: 'MIME类型',
      download: '下载',
      add: '新增',
      data: '数据',
      properties: '属性',
      insert: '插入',
      name: '名称',
      clear: '清除',
      seconds: '秒',
      options: '选项',
      discard: '丢弃',
      stay: '等待',
      author: '作者',
      upload: '上传',
      browse: '浏览',
      content: '内容',
      cut: '剪切',
      copy: '复制',
      paste: '粘贴',
      tools: '工具',
      format: '格式',
      all: '全部',
      duplicate: '重复',
      new: '新',
      history: '历史',
      select: '选择',
      filter: '过滤器',
      change: '变更',
      includes: '包含',
      completed: '已完成',
      aborted: '中止',
      disabled: '禁用',
      enable: '启用',
      disable: '禁用',
      contributors: '贡献者',
      pin: '固定',
      unpin: '取消固定',
      folder: '文件夹 | 文件夹',
      deleteConfirm: '您是否确认取消',
      uploadFile: '上传文件',
      manualValue: '手动值',
      selectAll: '选择全部',
      pageNumber: '页数',
      directoryPath: '目录路径',
      actionSuccessful: '{action} 成功',
      outputFormat: '输出格式',
      singleFile: '单个 {ext} 文件',
      zipCompressedFile: 'ZIP 压缩 {ext} 文件'
   },
   connection: {
      connectionName: '连接名称',
      client: '数据库类型',
      hostName: '主机名',
      port: '端口',
      user: '用户',
      password: '密码',
      credentials: '凭据',
      connect: '连接',
      connected: '已连接',
      disconnect: '断开连接',
      disconnected: '断开连接',
      ssl: 'SSL',
      privateKey: '私钥',
      certificate: '证书',
      caCertificate: 'CA 证书',
      ciphers: '密码',
      sshTunnel: 'SSH 隧道',
      passphrase: '密码短语',
      connectionString: '连接字符串',
      addConnection: '添加连接',
      createConnection: '创建连接',
      createNewConnection: '创建新连接',
      askCredentials: '询问凭据',
      testConnection: '测试连接',
      editConnection: '编辑连接',
      deleteConnection: '删除连接',
      connectionSuccessfullyMade: '连接成功了!',
      enableSsl: '启用 SSL',
      enableSsh: '启用 SSH',
      readOnlyMode: '只读模式',
      untrustedConnection: '不受信任的连接',
      allConnections: '所有连接',
      searchForConnections: '搜索连接'
   },
   database: {
      schema: '模式(schema)',
      type: '类型',
      foreignKeys: '外键',
      length: '长度',
      unsigned: '无符号',
      default: '默认',
      comment: '注释',
      collation: '排序规则',
      key: '键位 | 键位',
      order: '排序',
      expression: '表达式',
      autoIncrement: '自动增量',
      engine: '引擎',
      field: '字段 | 字段',
      approximately: '大约',
      total: '总计',
      table: '表',
      view: '视图',
      indexes: '索引',
      definer: '定义者',
      algorithm: '算法',
      trigger: '触发器 | 触发器',
      storedRoutine: '存储例程 | 存储例程',
      scheduler: '调度器 | 调度器',
      event: '事件',
      parameters: '参数',
      function: '函数 | 函数',
      deterministic: '确定的',
      context: '上下文',
      export: '导出',
      import: '导入',
      returns: '返回',
      timing: '定时',
      state: '状态',
      execution: '执行',
      starts: '开始',
      ends: '结束',
      variables: '变量',
      processes: '进程',
      database: '数据库',
      array: '数组',
      structure: '结构',
      row: '行 | 行',
      cell: '单元格 | 单元格',
      triggerFunction: '触发函数 | 触发函数',
      routine: '例程',
      commit: '提交',
      rollback: '回滚',
      resultsTable: '结果表',
      drop: '下降',
      unableEditFieldWithoutPrimary: '无法编辑结果集中一个没有主键的字段',
      editCell: '编辑单元格',
      deleteRows: '删除行 | 删除 {count} 行',
      confirmToDeleteRows: '您是否确认要删除一行? | 您是否确认要删除 {count} 行?',
      addNewRow: '添加新行',
      numberOfInserts: '插入的数量',
      affectedRows: '受影响的行',
      createNewDatabase: '创建新数据库',
      databaseName: '数据库名称',
      serverDefault: '默认服务器',
      deleteDatabase: '删除数据库',
      editDatabase: '编辑数据库',
      clearChanges: '清除更改',
      addNewField: '添加新字段',
      manageIndexes: '管理索引',
      manageForeignKeys: '管理外键',
      allowNull: '允许 NULL',
      zeroFill: '零填充',
      customValue: '自定义值',
      onUpdate: '在更新',
      deleteField: '删除字段',
      createNewIndex: '创建新索引',
      addToIndex: '添加到索引',
      createNewTable: '创建新表',
      emptyTable: '清空表',
      deleteTable: '删除表',
      emptyConfirm: '您是否确认清空',
      thereAreNoIndexes: '没有索引',
      thereAreNoForeign: '没有外键',
      createNewForeign: '创建新外键',
      referenceTable: '参考表',
      referenceField: '参考字段',
      foreignFields: '外键字段',
      invalidDefault: '无效的默认值',
      onDelete: '在删除',
      selectStatement: '选择语句',
      triggerStatement: '触发器语句',
      sqlSecurity: 'SQL 安全',
      updateOption: '更新选项',
      deleteView: '删除视图',
      createNewView: '创建新视图',
      deleteTrigger: '删除触发器',
      createNewTrigger: '创建新触发器',
      currentUser: '当前用户',
      routineBody: '例程主体',
      dataAccess: '数据访问',
      thereAreNoParameters: '没有参数',
      createNewParameter: '创建新参数',
      createNewRoutine: '创建新存储例程',
      deleteRoutine: '删除存储例程',
      functionBody: '函数体',
      createNewFunction: '创建新函数',
      deleteFunction: '删除函数',
      schedulerBody: '调度器主体',
      createNewScheduler: '创建新调度器',
      deleteScheduler: '删除调度器',
      preserveOnCompletion: '完成时保存',
      tableFiller: '表填充器',
      fakeDataLanguage: '伪造的数据语言',
      queryDuration: '查询时间',
      setNull: '设置 NULL',
      processesList: '进程列表',
      processInfo: '进程信息',
      manageUsers: '管理用户',
      createNewSchema: '创建新模式(schema)',
      schemaName: '模式名称',
      editSchema: '编辑模式',
      deleteSchema: '删除模式',
      duplicateTable: '重复的表',
      noSchema: '没有模式',
      runQuery: '运行查询',
      thereAreNoTableFields: '没有表的字段',
      newTable: '新表',
      newView: '新视图',
      newTrigger: '新触发器',
      newRoutine: '新例程',
      newFunction: '新函数',
      newScheduler: '新调度器',
      newTriggerFunction: '新触发函数',
      thereIsNoQueriesYet: '目前还没有任何查询',
      searchForQueries: '搜索查询',
      killProcess: '终止进程',
      exportSchema: '导出模式(schema)',
      importSchema: '导入模式(schema)',
      newInsertStmtEvery: '每条新的 INSERT 语句',
      processingTableExport: '处理 {table}',
      fetchingTableExport: '正在获取 {table} 数据',
      writingTableExport: '正在写入 {table} 数据',
      checkAllTables: '勾选所有表',
      uncheckAllTables: '不勾选所有表',
      killQuery: '取消查询',
      insertRow: '插入行 | 插入多行',
      commitMode: '提交模式',
      autoCommit: '自动提交',
      manualCommit: '手动提交',
      disableFKChecks: '禁用外键检查',
      formatQuery: '格式查询',
      queryHistory: '查询历史',
      clearQuery: '清除查询',
      fillCell: '填充单元格',
      executeSelectedQuery: '执行所选查询',
      importQueryErrors: '警告: 发生了 {n} 个错误 | 警告: 发生了 {n} 个错误',
      executedQueries: '{n} 个查询已执行 | {n} 个查询已执行'
   },
   application: {
      settings: '设置',
      general: '常规',
      themes: '主题',
      update: '更新',
      about: '关于',
      language: '语言',
      light: '明亮',
      dark: '暗黑',
      autoCompletion: '自动完成',
      application: '应用程序',
      editor: '编辑器',
      scratchpad: '草稿栏',
      changelog: '变更日志',
      small: '小',
      medium: '中',
      large: '大',
      console: '控制台',
      shortcuts: '快捷键',
      appearance: '外观',
      color: '颜色',
      label: '标签',
      icon: '图标',
      madeWithJS: '使用 💛 和 JavaScript 制作!',
      checkForUpdates: '检查更新',
      noUpdatesAvailable: '无可用更新',
      checkingForUpdate: '正在检查更新',
      checkFailure: '检查失败，请稍后再试',
      updateAvailable: '可用更新',
      downloadingUpdate: '正在下载更新',
      updateDownloaded: '已下载更新',
      restartToInstall: '重启 Antares 以进行安装',
      notificationsTimeout: '通知超时',
      openNewTab: '打开一个新标签',
      unsavedChanges: '未保存的更改',
      discardUnsavedChanges: '您有一些未保存的更改, 关闭此标签将放弃这些更改.',
      applicationTheme: '应用程序主题',
      editorTheme: '编辑器主题',
      wrapLongLines: '将长行换行显示',
      includeBetaUpdates: '包含测试版的更新',
      markdownSupported: '支持 Markdown',
      plantATree: '种植一棵树',
      dataTabPageSize: '数据标签的页面大小',
      noOpenTabs: '没有打开的标签, 请在左侧栏上导航或:',
      restorePreviousSession: '恢复上一个会话',
      closeTab: '关闭标签',
      goToDownloadPage: '转到下载页面',
      disableBlur: '禁用模糊',
      missingOrIncompleteTranslation: '有缺失或不完整的翻译?',
      findOutHowToContribute: '了解如何做出贡献',
      disableScratchpad: '禁用草稿栏',
      reportABug: '报告错误',
      nextTab: '下一个标签',
      previousTab: '上一个标签',
      selectTabNumber: '选择标签编号 {param}',
      toggleConsole: '切换控制台',
      addShortcut: '添加快捷键',
      editShortcut: '编辑快捷键',
      deleteShortcut: '删除快捷键',
      restoreDefaults: '恢复默认值',
      restoreDefaultsQuestion: '是否确认恢复默认值?',
      registerAShortcut: '注册快捷键',
      invalidShortcutMessage: '无效组合,请继续输入',
      shortcutAlreadyExists: '快捷键已经存在',
      saveContent: '保存内容',
      openAllConnections: '打开全部连接',
      openSettings: '打开设置',
      openScratchpad: '打开草稿栏',
      runOrReload: '运行或重新加载',
      openFilter: '打开过滤器',
      nextResultsPage: '下一个结果页',
      previousResultsPage: '上一个结果页',
      editFolder: '编辑文件夹',
      folderName: '文件夹名称',
      deleteFolder: '删除文件夹',
      editConnectionAppearance: '编辑连接的外观',
      defaultCopyType: '默认复制类型',
      showTableSize: '在侧边栏显示表大小',
      showTableSizeDescription: '仅限 MySQL/MariaDB. 启用此选项可能会影响许多表的模式(schema)的性能.',
      searchForElements: '搜索元素'
   },
   faker: {
      address: '地址',
      commerce: '商业',
      company: '公司',
      database: '数据库',
      date: '日期',
      finance: '财务',
      git: 'Git',
      hacker: '黑客',
      internet: '互联网',
      lorem: 'Lorem',
      name: '姓名',
      music: '音乐',
      phone: '电话',
      random: '随机',
      system: '系统',
      time: '时间',
      vehicle: '车辆',
      zipCode: '邮政编码',
      zipCodeByState: '各州的邮政编码',
      city: '城市',
      cityPrefix: '城市前缀',
      citySuffix: '城市后缀',
      streetName: '街道名称',
      streetAddress: '街道地址',
      streetSuffix: '街道后缀',
      streetPrefix: '街道前缀',
      secondaryAddress: '次要地址',
      county: '县',
      country: '国家',
      countryCode: '国家代码',
      state: '州',
      stateAbbr: '州简称',
      latitude: '纬度',
      longitude: '经度',
      direction: '方向',
      cardinalDirection: '方位',
      ordinalDirection: '顺序方向',
      nearbyGPSCoordinate: '附近的 GPS 坐标',
      timeZone: '时区',
      color: '颜色',
      department: '部门',
      productName: '产品名称',
      price: '价格',
      productAdjective: '产品形容词',
      productMaterial: '产品材料',
      product: '产品',
      productDescription: '产品说明',
      suffixes: '后缀',
      companyName: '公司名称',
      companySuffix: '公司后缀',
      catchPhrase: '流行语',
      bs: 'BS',
      catchPhraseAdjective: '流行语形容词',
      catchPhraseDescriptor: '流行语说明',
      catchPhraseNoun: '流行语名词',
      bsAdjective: 'BS 形容词',
      bsBuzz: 'BS 嗡嗡声',
      bsNoun: 'BS 名称',
      column: '列',
      type: '类型',
      collation: '排序规则',
      engine: '引擎',
      past: '过去',
      now: '现在',
      future: '未来',
      between: '之间',
      recent: '最近',
      soon: '很快',
      month: '月',
      weekday: '工作日',
      account: '账户',
      accountName: '账户名称',
      routingNumber: '路由编号',
      mask: '掩码',
      amount: '金额',
      transactionType: '交易类型',
      currencyCode: '货币代码',
      currencyName: '货币名称',
      currencySymbol: '货币符号',
      bitcoinAddress: '比特币地址',
      litecoinAddress: '莱特币地址',
      creditCardNumber: '信用卡号码',
      creditCardCVV: '信用卡CVV',
      ethereumAddress: '以太坊地址',
      iban: 'Iban',
      bic: 'Bic',
      transactionDescription: '交易描述',
      branch: '分支',
      commitEntry: '提交条目',
      commitMessage: '提交信息',
      commitSha: '提交 SHA',
      shortSha: '短的 SHA',
      abbreviation: '缩写',
      adjective: '形容词',
      noun: '名词',
      verb: '动词',
      ingverb: '英式动词',
      phrase: '短语',
      avatar: '头像',
      email: '电子邮箱',
      exampleEmail: '示例电子邮件',
      userName: '用户名',
      protocol: '协议',
      url: '统一资源定位地址',
      domainName: '域名',
      domainSuffix: '域名后缀',
      domainWord: '域词',
      ip: 'Ip',
      ipv6: 'Ipv6',
      userAgent: '用户代理',
      mac: 'Mac',
      password: '密码',
      word: '单词',
      words: '单词',
      sentence: '句子',
      slug: 'Slug',
      sentences: '句子',
      paragraph: '段落',
      paragraphs: '段落',
      text: '文本',
      lines: '行',
      genre: '类型',
      firstName: '名',
      lastName: '姓氏',
      middleName: '中间名',
      findName: '全名',
      jobTitle: '职位名称',
      gender: '性别',
      prefix: '前缀',
      suffix: '后缀',
      title: '头衔',
      jobDescriptor: '工作描述',
      jobArea: '工作领域',
      jobType: '工作类型',
      phoneNumber: '电话号码',
      phoneNumberFormat: '电话号码格式',
      phoneFormats: '电话格式',
      number: '号码',
      float: 'Float',
      arrayElement: '数组元素',
      arrayElements: '数组元素',
      objectElement: '对象元素',
      uuid: 'Uuid',
      boolean: '布尔型',
      image: '镜像',
      locale: '区域',
      alpha: '阿尔法',
      alphaNumeric: 'α 数字',
      hexaDecimal: '十六进制',
      fileName: '文件名',
      commonFileName: '普通文件名',
      mimeType: 'MIME类型',
      commonFileType: '常见文件类型',
      commonFileExt: '常见文件扩展名',
      fileType: '文件类型',
      fileExt: '文件扩展名',
      directoryPath: '目录路径',
      filePath: '文件路径',
      semver: 'Semver',
      manufacturer: '制造商',
      model: '型号',
      fuel: 'Fuel',
      vin: 'Vin'
   }
};
